using Plots

"""
    Create plots comparing the Julia & PySDM vertical profiles
"""
function plot_comparison(KM; sdm_case = "dry", name = "dry")
    sdm_data = load_sdm_data(sdm_case)
    path = joinpath(@__DIR__, "output")
    mkpath(path)

    fig_name = string(name, "_init_profile.png")

    p1 = Plots.plot(KM.q_vap, KM.z_centers, label = "KM", xlabel = "q_vap [g/kg]", ylabel = "z [m]")
    Plots.plot!(p1, sdm_data.qv_sdm, sdm_data.z_sdm, label = "SDM")

    p2 = Plots.plot(KM.ρ, KM.z_centers, label = "KM ρ_tot", xlabel = "ρ [kg/m3]", ylabel = "z [m]")
    Plots.plot!(p2, sdm_data.rho_sdm, sdm_data.z_sdm, label = "SDM ρ")

    p3 = Plots.plot(KM.θ_dry, KM.z_centers, label = "KM", xlabel = "θ_dry [K]", ylabel = "z [m]")
    Plots.plot!(p3, sdm_data.thetad_sdm, sdm_data.z_sdm, label = "SDM")

    p4 = Plots.plot(KM.T, KM.z_centers, label = "KM", xlabel = "T [K]", ylabel = "z [m]")
    Plots.plot!(p4, sdm_data.T_sdm, sdm_data.z_sdm, label = "SDM")

    p5 = Plots.plot(KM.p ./ 100, KM.z_centers, label = "KM", xlabel = "p [hPa]", ylabel = "z [m]")
    Plots.plot!(p5, sdm_data.P_sdm ./ 100, sdm_data.z_sdm, label = "SDM")

    p6 = Plots.plot(KM.q_liq, KM.z_centers, label = "KM", xlabel = "q_liq [g/kg]", ylabel = "z [m]")
    Plots.plot!(p6, sdm_data.ql_sdm, sdm_data.z_sdm, label = "SDM")

    p = Plots.plot(
        p1,
        p2,
        p3,
        p4,
        p5,
        p6,
        size = (1200.0, 750.0),
        bottom_margin = 40.0 * Plots.PlotMeasures.px,
        left_margin = 80.0 * Plots.PlotMeasures.px,
    )
    Plots.png(p, joinpath(path, fig_name))
end

"""
    Load the statically-stored PySDM profiles
"""
function load_sdm_data(case = "dry")

#! format: off
    if case=="dry"
        z_sdm = [10.,   30.,   50.,   70.,   90.,  110.,  130.,  150.,  170.,  190.,  210.,  230.,
        250.,  270.,  290.,  310.,  330.,  350.,  370.,  390.,  410.,  430.,  450.,  470.,
        490.,  510.,  530.,  550.,  570.,  590.,  610.,  630.,  650.,  670.,  690.,  710.,
        730.,  750.,  770.,  790.,  810.,  830.,  850.,  870.,  890.,  910.,  930.,  950.,
        970.,  990., 1010., 1030., 1050., 1070., 1090., 1110., 1130., 1150., 1170., 1190.,
        1210., 1230., 1250., 1270., 1290., 1310., 1330., 1350., 1370., 1390., 1410., 1430.,
        1450., 1470., 1490., 1510., 1530., 1550., 1570., 1590., 1610., 1630., 1650., 1670.,
        1690., 1710., 1730., 1750., 1770., 1790., 1810., 1830., 1850., 1870., 1890., 1910.,
        1930., 1950., 1970., 1990., 2010., 2030., 2050., 2070., 2090., 2110., 2130., 2150.,
        2170., 2190., 2210., 2230., 2250., 2270., 2290., 2310., 2330., 2350., 2370., 2390.,
        2410., 2430., 2450., 2470., 2490., 2510., 2530., 2550., 2570., 2590., 2610., 2630.,
        2650., 2670., 2690., 2710., 2730., 2750., 2770., 2790., 2810., 2830., 2850., 2870.,
        2890., 2910., 2930., 2950., 2970., 2990.]

        ql_sdm = [0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.,
        0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.,
        0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.,
        0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.,
        0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.,
        0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.,
        0., 0., 0., 0., 0., 0.]

        qv_sdm = [0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.,
        0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.,
        0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.,
        0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.,
        0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.,
        0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.,
        0., 0., 0., 0., 0., 0.]

        rhod_sdm = [1.17447981, 1.17255909, 1.17064027, 1.16872332, 1.16680827, 1.1648951,
        1.16298381, 1.16107441, 1.15916689, 1.15726125, 1.15535749, 1.15345562,
        1.15155562, 1.14965751, 1.14776127, 1.14586692, 1.14397444, 1.14208384,
        1.14019511, 1.13830826, 1.13642329, 1.13454019, 1.13265897, 1.13077962,
        1.12890214, 1.12702654, 1.12515281, 1.12328094, 1.12141095, 1.11954283,
        1.11767658, 1.1158122,  1.11394968, 1.11208904, 1.11023026, 1.10837334,
        1.10651829, 1.10466524, 1.10281494, 1.10096751, 1.09912296, 1.09728128,
        1.09544246, 1.0936065,  1.0917734,  1.08994314, 1.08811573, 1.08629116,
        1.08446943, 1.08265053, 1.08083445, 1.0790212,  1.07721077, 1.07540315,
        1.07359833, 1.07179632, 1.06999712, 1.0682007,  1.06640708, 1.06461624,
        1.06282819, 1.06104291, 1.05926041, 1.05748067, 1.0557037,  1.05392949,
        1.05215803, 1.05038932, 1.04862336, 1.04686014, 1.04509966, 1.04334192,
        1.0415869,  1.0398346,  1.03808502, 1.03633817, 1.03459402, 1.03285257,
        1.03111384, 1.02937779, 1.02764445, 1.02591379, 1.02418582, 1.02246053,
        1.02073791, 1.01901797, 1.01730069, 1.01558608, 1.01387413, 1.01216484,
        1.01045819, 1.00875419, 1.00705284, 1.00535412, 1.00365804, 1.00196459,
        1.00027376, 0.99858556, 0.99689997, 0.995217,   0.99353663, 0.99185887,
        0.99018371, 0.98851115, 0.98684118, 0.9851738,  0.98350901, 0.98184679,
        0.98018715, 0.97853008, 0.97687558, 0.97522364, 0.97357427, 0.97192745,
        0.97028318, 0.96864145, 0.96700228, 0.96536564, 0.96373153, 0.96209996,
        0.96047092, 0.9588444,  0.9572204,  0.95559891, 0.95397993, 0.95236347,
        0.9507495,  0.94913804, 0.94752907, 0.9459226,  0.94431861, 0.9427171,
        0.94111808, 0.93952153, 0.93792745, 0.93633584, 0.9347467,  0.93316001,
        0.93157578, 0.92999401, 0.92841468, 0.9268378,  0.92526336, 0.92369135,
        0.92212178, 0.92055464, 0.91898993, 0.91742763, 0.91586776, 0.9143103]

        thetad_sdm = [297.9,        297.9,        297.9,        297.9,        297.9,
        297.9,        297.9,        297.9,        297.9,        297.9,
        297.9,        297.9,        297.9,        297.9,        297.9,
        297.9,        297.9,        297.9,        297.9,        297.9,
        297.9,        297.9,        297.9,        297.9,        297.9,
        297.9,        297.9,        297.9,        297.9,        297.9,
        297.9,        297.9,        297.9,        297.9,        297.9,
        297.9,        297.9,        297.95857143, 298.07571429, 298.19285714,
        298.31,       298.42714286, 298.54428571, 298.66142857, 298.77857143,
        298.89571429, 299.01285714, 299.13,       299.24714286, 299.36428571,
        299.48142857, 299.59857143, 299.71571429, 299.83285714, 299.95,
        300.06714286, 300.18428571, 300.30142857, 300.41857143, 300.53571429,
        300.65285714, 300.77,       300.88714286, 301.00428571, 301.12142857,
        301.23857143, 301.35571429, 301.47285714, 301.59,       301.70714286,
        301.82428571, 301.94142857, 302.05857143, 302.17571429, 302.29285714,
        302.41,       302.52714286, 302.64428571, 302.76142857, 302.87857143,
        302.99571429, 303.11285714, 303.23,       303.34714286, 303.46428571,
        303.58142857, 303.69857143, 303.81571429, 303.93285714, 304.05,
        304.16714286, 304.28428571, 304.40142857, 304.51857143, 304.63571429,
        304.75285714, 304.87,       304.98714286, 305.10428571, 305.22142857,
        305.33857143, 305.45571429, 305.57285714, 305.69,       305.80714286,
        305.92428571, 306.04142857, 306.15857143, 306.27571429, 306.39285714,
        306.51,       306.62714286, 306.74428571, 306.86142857, 306.97857143,
        307.09571429, 307.21285714, 307.33,       307.44714286, 307.56428571,
        307.68142857, 307.79857143, 307.91571429, 308.03285714, 308.15,
        308.26714286, 308.38428571, 308.50142857, 308.61857143, 308.73571429,
        308.85285714, 308.97,       309.08714286, 309.20428571, 309.32142857,
        309.43857143, 309.55571429, 309.67285714, 309.79,       309.90714286,
        310.02428571, 310.14142857, 310.25857143, 310.37571429, 310.49285714,
        310.61,       310.72714286, 310.84428571, 310.96142857, 311.07857143]

        T_sdm = [298.39451096, 298.19935374, 298.00419653, 297.80903931, 297.6138821,
        297.41872489, 297.22356767, 297.02841046, 296.83325325, 296.63809603,
        296.44293882, 296.2477816,  296.05262439, 295.85746718, 295.66230996,
        295.46715275, 295.27199553, 295.07683832, 294.88168111, 294.68652389,
        294.49136668, 294.29620946, 294.10105225, 293.90589504, 293.71073782,
        293.51558061, 293.32042339, 293.12526618, 292.93010897, 292.73495175,
        292.53979454, 292.34463732, 292.14948011, 291.9543229,  291.75916568,
        291.56400847, 291.36885126, 291.25384371, 291.21892374, 291.18392159,
        291.14883726, 291.11367078, 291.07842218, 291.04309146, 291.00767865,
        290.97218377, 290.93660683, 290.90094787, 290.86520688, 290.82938391,
        290.79347895, 290.75749204, 290.7214232,  290.68527243, 290.64903977,
        290.61272523, 290.57632882, 290.53985058, 290.50329051, 290.46664864,
        290.42992499, 290.39311957, 290.35623241, 290.31926352, 290.28221292,
        290.24508063, 290.20786668, 290.17057107, 290.13319384, 290.09573499,
        290.05819455, 290.02057253, 289.98286896, 289.94508386, 289.90721723,
        289.86926911, 289.83123951, 289.79312845, 289.75493595, 289.71666202,
        289.6783067,  289.63986998, 289.60135191, 289.56275248, 289.52407173,
        289.48530967, 289.44646631, 289.40754169, 289.36853581, 289.3294487,
        289.29028038, 289.25103086, 289.21170016, 289.1722883,  289.1327953,
        289.09322118, 289.05356596, 289.01382966, 288.97401229, 288.93411387,
        288.89413442, 288.85407397, 288.81393253, 288.77371011, 288.73340674,
        288.69302244, 288.65255722, 288.6120111,  288.5713841,  288.53067625,
        288.48988755, 288.44901803, 288.4080677,  288.36703659, 288.32592471,
        288.28473208, 288.24345872, 288.20210465, 288.16066988, 288.11915444,
        288.07755835, 288.03588161, 287.99412426, 287.9522863,  287.91036776,
        287.86836866, 287.82628901, 287.78412883, 287.74188814, 287.69956696,
        287.65716531, 287.6146832,  287.57212066, 287.5294777,  287.48675434,
        287.44395059, 287.40106649, 287.35810204, 287.31505726, 287.27193218,
        287.2287268,  287.18544116, 287.14207525, 287.09862912, 287.05510276,
        287.01149621, 286.96780948, 286.92404258, 286.88019554, 286.83626837]

        P_sdm = [100582.48811972, 100352.32225996, 100122.53293069,  99893.11976192,
        99664.08238378,  99435.42042652,  99207.13352051,  98979.22129625,
        98751.68338435,  98524.51941556,  98297.72902072,  98071.31183083,
        97845.26747698,  97619.5955904,   97394.29580244,  97169.36774457,
        96944.81104837,  96720.62534556,  96496.81026797,  96273.36544757,
        96050.29051643,  95827.58510676,  95605.24885087,  95383.28138121,
        95161.68233036,  94940.451331,    94719.58801595,  94499.09201814,
        94278.96297063,  94059.2005066,   93839.80425936,  93620.77386233,
        93402.10894907,  93183.80915323,  92965.87410862,  92748.30344915,
        92531.09680887,  92339.67545412,  92173.95501465,  92008.48617995,
        91843.26861151,  91678.30197128,  91513.58592168,  91349.12012558,
        91184.9042463,   91020.93794762,  90857.2208938,   90693.75274953,
        90530.53317996,  90367.56185069,  90204.83842778,  90042.36257776,
        89880.13396757,  89718.15226463,  89556.41713682,  89394.92825244,
        89233.68528025,  89072.68788948,  88911.93574978,  88751.42853125,
        88591.16590445,  88431.14754038,  88271.37311048,  88111.84228664,
        87952.55474118,  87793.51014689,  87634.70817696,  87476.14850508,
        87317.83080531,  87159.75475222,  87001.92002076,  86844.32628635,
        86686.97322485,  86529.86051254,  86372.98782615,  86216.35484284,
        86059.9612402,   85903.80669626,  85747.89088949,  85592.21349879,
        85436.77420347,  85281.57268331,  85126.60861849,  84971.88168963,
        84817.39157779,  84663.13796443,  84509.12053148,  84355.33896126,
        84201.79293654,  84048.48214049,  83895.40625675,  83742.56496934,
        83589.95796273,  83437.58492179,  83285.44553185,  83133.53947862,
        82981.86644827,  82830.42612736,  82679.21820288,  82528.24236226,
        82377.49829331,  82226.98568428,  82076.70422385,  81926.6536011,
        81776.83350552,  81627.24362703,  81477.88365596,  81328.75328305,
        81179.85219946,  81031.18009676,  80882.73666694,  80734.52160238,
        80586.5345959,   80438.7753407,   80291.24353041,  80143.93885907,
        79996.86102112,  79850.00971141,  79703.3846252,   79556.98545815,
        79410.81190633,  79264.86366621,  79119.14043468,  78973.64190902,
        78828.36778691,  78683.31776645,  78538.49154613,  78393.88882483,
        78249.50930186,  78105.35267691,  77961.41865007,  77817.70692184,
        77674.21719311,  77530.94916515,  77387.90253968,  77245.07701875,
        77102.47230486,  76960.08810087,  76817.92411006,  76675.98003608,
        76534.255583,    76392.75045525,  76251.46435769,  76110.39699554,
        75969.54807443,  75828.91730037,  75688.50437977,  75548.30901941,
        75408.33092649,  75268.56980856]

    elseif case=="wet"
        z_sdm = [10.,   30.,   50.,   70.,   90.,  110.,  130.,  150.,  170.,  190.,  210.,  230.,
        250.,  270.,  290.,  310.,  330.,  350.,  370.,  390.,  410.,  430.,  450.,  470.,
        490.,  510.,  530.,  550.,  570.,  590.,  610.,  630.,  650.,  670.,  690.,  710.,
        730.,  750.,  770.,  790.,  810.,  830.,  850.,  870.,  890.,  910.,  930.,  950.,
        970.,  990., 1010., 1030., 1050., 1070., 1090., 1110., 1130., 1150., 1170., 1190.,
       1210., 1230., 1250., 1270., 1290., 1310., 1330., 1350., 1370., 1390., 1410., 1430.,
       1450., 1470., 1490., 1510., 1530., 1550., 1570., 1590., 1610., 1630., 1650., 1670.,
       1690., 1710., 1730., 1750., 1770., 1790., 1810., 1830., 1850., 1870., 1890., 1910.,
       1930., 1950., 1970., 1990., 2010., 2030., 2050., 2070., 2090., 2110., 2130., 2150.,
       2170., 2190., 2210., 2230., 2250., 2270., 2290., 2310., 2330., 2350., 2370., 2390.,
       2410., 2430., 2450., 2470., 2490., 2510., 2530., 2550., 2570., 2590., 2610., 2630.,
       2650., 2670., 2690., 2710., 2730., 2750., 2770., 2790., 2810., 2830., 2850., 2870.,
       2890., 2910., 2930., 2950., 2970., 2990.]

        ql_sdm = [0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.,
        0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.,
        0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.,
        0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.,
        0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.,
        0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.,
        0., 0., 0., 0., 0., 0.]

        qv_sdm = [0.01498378, 0.01495135, 0.01491892, 0.01488649, 0.01485405, 0.01482162,
        0.01478919, 0.01475676, 0.01472432, 0.01469189, 0.01465946, 0.01462703,
        0.01459459, 0.01456216, 0.01452973, 0.0144973,  0.01446486, 0.01443243,
        0.0144,     0.01436757, 0.01433514, 0.0143027,  0.01427027, 0.01423784,
        0.01420541, 0.01417297, 0.01414054, 0.01410811, 0.01407568, 0.01404324,
        0.01401081, 0.01397838, 0.01394595, 0.01391351, 0.01388108, 0.01384865,
        0.01381622, 0.01375476, 0.01366429, 0.01357381, 0.01348333, 0.01339286,
        0.01330238, 0.0132119,  0.01312143, 0.01303095, 0.01294048, 0.01285,
        0.01275952, 0.01266905, 0.01257857, 0.0124881,  0.01239762, 0.01230714,
        0.01221667, 0.01212619, 0.01203571, 0.01194524, 0.01185476, 0.01176429,
        0.01167381, 0.01158333, 0.01149286, 0.01140238, 0.0113119,  0.01122143,
        0.01113095, 0.01104048, 0.01095,    0.01085952, 0.01076905, 0.01067857,
        0.0105881,  0.01049762, 0.01040714, 0.01031667, 0.01022619, 0.01013571,
        0.01004524, 0.00995476, 0.00986429, 0.00977381, 0.00968333, 0.00959286,
        0.00950238, 0.0094119,  0.00932143, 0.00923095, 0.00914048, 0.00905,
        0.00895952, 0.00886905, 0.00877857, 0.0086881,  0.00859762, 0.00850714,
        0.00841667, 0.00832619, 0.00823571, 0.00814524, 0.00805476, 0.00796429,
        0.00787381, 0.00778333, 0.00769286, 0.00760238, 0.0075119,  0.00742143,
        0.00733095, 0.00724048, 0.00715,    0.00705952, 0.00696905, 0.00687857,
        0.0067881,  0.00669762, 0.00660714, 0.00651667, 0.00642619, 0.00633571,
        0.00624524, 0.00615476, 0.00606429, 0.00597381, 0.00588333, 0.00579286,
        0.00570238, 0.0056119,  0.00552143, 0.00543095, 0.00534048, 0.00525,
        0.00515952, 0.00506905, 0.00497857, 0.0048881,  0.00479762, 0.00470714,
        0.00461667, 0.00452619, 0.00443571, 0.00434524, 0.00425476, 0.00416429,
        0.00407381, 0.00398333, 0.00389286, 0.00380238, 0.0037119,  0.00362143]

        rhod_sdm = [1.14684273, 1.14501793, 1.14319479, 1.1413733,  1.13955347, 1.13773529,
        1.13591876, 1.13410388, 1.13229066, 1.13047909, 1.12866917, 1.1268609,
        1.12505429, 1.12324932, 1.121446,   1.11964434, 1.11784432, 1.11604595,
        1.11424924, 1.11245417, 1.11066075, 1.10886897, 1.10707885, 1.10529037,
        1.10350354, 1.10171836, 1.09993482, 1.09815293, 1.09637269, 1.09459409,
        1.09281714, 1.09104183, 1.08926817, 1.08749615, 1.08572578, 1.08395704,
        1.08218996, 1.0804523,  1.07875114, 1.07705233, 1.07535588, 1.07366178,
        1.07197004, 1.07028064, 1.06859359, 1.06690887, 1.0652265,  1.06354646,
        1.06186874, 1.06019336, 1.0585203,  1.05684956, 1.05518114, 1.05351503,
        1.05185123, 1.05018974, 1.04853055, 1.04687366, 1.04521907, 1.04356677,
        1.04191677, 1.04026905, 1.03862362, 1.03698046, 1.03533959, 1.03370099,
        1.03206466, 1.03043059, 1.0287988,  1.02716926, 1.02554198, 1.02391696,
        1.02229419, 1.02067366, 1.01905538, 1.01743935, 1.01582555, 1.01421399,
        1.01260466, 1.01099756, 1.00939269, 1.00779004, 1.00618961, 1.00459139,
        1.00299539, 1.0014016,  0.99981002, 0.99822064, 0.99663346, 0.99504848,
        0.99346569, 0.9918851,  0.99030669, 0.98873047, 0.98715643, 0.98558457,
        0.98401489, 0.98244738, 0.98088204, 0.97931887, 0.97775786, 0.97619901,
        0.97464232, 0.97308778, 0.9715354,  0.96998516, 0.96843707, 0.96689112,
        0.96534731, 0.96380564, 0.9622661,  0.96072869, 0.95919341, 0.95766025,
        0.95612922, 0.9546003,  0.9530735,  0.95154881, 0.95002623, 0.94850575,
        0.94698738, 0.94547112, 0.94395694, 0.94244487, 0.94093488, 0.93942699,
        0.93792118, 0.93641745, 0.9349158,  0.93341623, 0.93191873, 0.93042331,
        0.92892995, 0.92743866, 0.92594944, 0.92446227, 0.92297716, 0.9214941,
        0.92001309, 0.91853413, 0.91705722, 0.91558235, 0.91410952, 0.91263873,
        0.91116997, 0.90970324, 0.90823854, 0.90677586, 0.90531521, 0.90385658]

        thetad_sdm = [299.93246324, 299.92810105, 299.9237387,  299.9193762,  299.91501353,
        299.91065071, 299.90628773, 299.90192459, 299.89756129, 299.89319783,
        299.88883422, 299.88447044, 299.88010651, 299.87574242, 299.87137816,
        299.86701375, 299.86264918, 299.85828446, 299.85391957, 299.84955452,
        299.84518932, 299.84082395, 299.83645843, 299.83209275, 299.8277269,
        299.8233609,  299.81899474, 299.81462843, 299.81026195, 299.80589531,
        299.80152851, 299.79716156, 299.79279445, 299.78842717, 299.78405974,
        299.77969215, 299.7753244,  299.82598628, 299.93166981, 300.03734251,
        300.14300438, 300.24865542, 300.35429564, 300.45992502, 300.56554357,
        300.67115128, 300.77674816, 300.8823342,  300.98790939, 301.09347375,
        301.19902726, 301.30456992, 301.41010174, 301.51562271, 301.62113282,
        301.72663208, 301.83212049, 301.93759804, 302.04306474, 302.14852057,
        302.25396554, 302.35939964, 302.46482289, 302.57023526, 302.67563676,
        302.7810274,  302.88640716, 302.99177605, 303.09713406, 303.20248119,
        303.30781744, 303.41314281, 303.5184573,  303.6237609,  303.72905362,
        303.83433545, 303.93960638, 304.04486643, 304.15011558, 304.25535383,
        304.36058119, 304.46579764, 304.5710032,  304.67619785, 304.7813816,
        304.88655444, 304.99171638, 305.0968674,  305.20200751, 305.30713671,
        305.41225499, 305.51736235, 305.6224588,  305.72754432, 305.83261892,
        305.9376826,  306.04273535, 306.14777717, 306.25280806, 306.35782802,
        306.46283705, 306.56783514, 306.6728223,  306.77779851, 306.88276379,
        306.98771812, 307.09266151, 307.19759395, 307.30251544, 307.40742599,
        307.51232558, 307.61721422, 307.7220919,  307.82695863, 307.93181439,
        308.0366592,  308.14149305, 308.24631593, 308.35112784, 308.45592879,
        308.56071876, 308.66549777, 308.7702658,  308.87502286, 308.97976894,
        309.08450404, 309.18922816, 309.29394129, 309.39864345, 309.50333462,
        309.60801479, 309.71268398, 309.81734218, 309.92198939, 310.0266256,
        310.13125081, 310.23586502, 310.34046824, 310.44506045, 310.54964165,
        310.65421185, 310.75877105, 310.86331923, 310.9678564,  311.07238256,
        311.1768977,  311.28140183, 311.38589493, 311.49037702, 311.59484808]

        T_sdm = [298.39416911, 298.19822189, 298.00227284, 297.80632197, 297.61036927,
        297.41441475, 297.21845841, 297.02250024, 296.82654025, 296.63057843,
        296.43461479, 296.23864933, 296.04268204, 295.84671293, 295.65074199,
        295.45476923, 295.25879464, 295.06281823, 294.86683999, 294.67085993,
        294.47487805, 294.27889434, 294.0829088,  293.88692144, 293.69093226,
        293.49494125, 293.29894841, 293.10295375, 292.90695726, 292.71095895,
        292.51495882, 292.31895685, 292.12295307, 291.92694745, 291.73094002,
        291.53493075, 291.33891966, 291.22071356, 291.18094381, 291.14107989,
        291.1011218,  291.06106956, 291.02092318, 290.98068268, 290.94034807,
        290.89991936, 290.85939658, 290.81877973, 290.77806883, 290.73726389,
        290.69636493, 290.65537197, 290.61428501, 290.57310407, 290.53182917,
        290.49046031, 290.44899753, 290.40744082, 290.3657902,  290.32404569,
        290.2822073,  290.24027505, 290.19824895, 290.15612901, 290.11391525,
        290.07160769, 290.02920633, 289.9867112,  289.94412229, 289.90143964,
        289.85866326, 289.81579315, 289.77282934, 289.72977183, 289.68662064,
        289.64337579, 289.60003729, 289.55660515, 289.51307939, 289.46946002,
        289.42574706, 289.38194052, 289.33804041, 289.29404675, 289.24995955,
        289.20577883, 289.1615046,  289.11713687, 289.07267567, 289.028121,
        288.98347287, 288.9387313,  288.89389631, 288.84896791, 288.80394611,
        288.75883093, 288.71362238, 288.66832047, 288.62292523, 288.57743665,
        288.53185477, 288.48617958, 288.44041111, 288.39454937, 288.34859437,
        288.30254613, 288.25640465, 288.21016996, 288.16384207, 288.117421,
        288.07090674, 288.02429933, 287.97759877, 287.93080508, 287.88391827,
        287.83693836, 287.78986535, 287.74269927, 287.69544013, 287.64808793,
        287.6006427,  287.55310445, 287.50547318, 287.45774893, 287.40993169,
        287.36202149, 287.31401833, 287.26592224, 287.21773321, 287.16945128,
        287.12107645, 287.07260873, 287.02404814, 286.9753947,  286.92664841,
        286.87780929, 286.82887735, 286.77985261, 286.73073508, 286.68152478,
        286.63222172, 286.5828259,  286.53333736, 286.48375609, 286.43408211,
        286.38431544, 286.33445609, 286.28450407, 286.2344594,  286.18432209]

        P_sdm = [100582.08462059, 100350.98846171, 100120.26974007,  99889.92809168,
        99659.96315268,  99430.37455928,  99201.16194782,  98972.32495472,
        98743.86321652,  98515.77636986,  98288.06405148,  98060.72589823,
        97833.76154706,  97607.17063501,  97380.95279925,  97155.10767704,
        96929.63490573,  96704.53412281,  96479.80496583,  96255.44707247,
        96031.46008052,  95807.84362785,  95584.59735246,  95361.72089243,
        95139.21388596,  94917.07597135,  94695.30678701,  94473.90597144,
        94252.87316326,  94032.20800117,  93811.91012402,  93591.97917071,
        93372.41478028,  93153.21659187,  92934.38424472,  92715.91737817,
        92497.81563166,  92302.89996349,  92131.86762153,  91961.09175106,
        91790.57203362,  91620.30815114,  91450.29978592,  91280.54662065,
        91111.04833839,  90941.80462258,  90772.81515703,  90604.07962595,
        90435.5977139,   90267.36910583,  90099.39348705,  89931.67054326,
        89764.19996053,  89596.98142531,  89430.0146244,   89263.299245,
        89096.83497465,  88930.6215013,   88764.65851324,  88598.94569915,
        88433.48274805,  88268.26934936,  88103.30519287,  87938.5899687,
        87774.12336738,  87609.90507978,  87445.93479715,  87282.2122111,
        87118.7370136,   86955.508897,    86792.527554,    86629.79267767,
        86467.30396144,  86305.06109911,  86143.06378482,  85981.31171311,
        85819.80457884,  85658.54207726,  85497.52390396,  85336.7497549,
        85176.21932641,  85015.93231514,  84855.88841815,  84696.08733282,
        84536.52875689,  84377.21238847,  84218.13792601,  84059.30506835,
        83900.71351463,  83742.36296439,  83584.25311749,  83426.38367419,
        83268.75433504,  83111.364801,    82954.21477335,  82797.30395371,
        82640.6320441,   82484.19874683,  82328.0037646,   82172.04680045,
        82016.32755777,  81860.84574028,  81705.60105206,  81550.59319756,
        81395.82188154,  81241.28680912,  81086.98768578,  80932.92421732,
        80779.09610989,  80625.50307001,  80472.14480452,  80319.0210206,
        80166.13142578,  80013.47572795,  79861.0536353,   79708.86485639,
        79556.90910014,  79405.18607575,  79253.69549283,  79102.43706127,
        78951.41049134,  78800.61549363,  78650.05177906,  78499.71905891,
        78349.61704477,  78199.74544859,  78050.10398265,  77900.69235955,
        77751.51029225,  77602.55749403,  77453.83367849,  77305.33855959,
        77157.07185161,  77009.03326917,  76861.22252721,  76713.639341,
        76566.28342616,  76419.15449863,  76272.25227467,  76125.57647089,
        75979.12680421,  75832.9029919,   75686.90475153,  75541.13180102,
        75395.58385861,  75250.26064287,  75105.1618727,   74960.28726731,
        74815.63654625,  74671.20942939]


    elseif case=="wet_coarse"
            # Reference data from PySDM
        z_sdm = [50.,  150.,  250.,  350.,  450.,  550.,  650.,  750.,  850.,  950., 1050., 1150.,
        1250., 1350., 1450., 1550., 1650., 1750., 1850., 1950., 2050., 2150., 2250., 2350.,
        2450., 2550., 2650., 2750., 2850., 2950.]

        ql_sdm = [0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.,
        0., 0., 0., 0., 0., 0.]

        qv_sdm = [0.01491892, 0.01475676, 0.01459459, 0.01443243, 0.01427027, 0.01410811,
        0.01394595, 0.01375476, 0.01330238, 0.01285,    0.01239762, 0.01194524,
        0.01149286, 0.01104048, 0.0105881,  0.01013571, 0.00968333, 0.00923095,
        0.00877857, 0.00832619, 0.00787381, 0.00742143, 0.00696905, 0.00651667,
        0.00606429, 0.0056119,  0.00515952, 0.00470714, 0.00425476, 0.00380238]

        rhod_sdm = [1.14213163, 1.13304574, 1.12400115, 1.11499782, 1.10603571, 1.09711479,
        1.08823501, 1.07943064, 1.07095554, 1.06253658, 1.05417585, 1.04587296,
        1.03762748, 1.029439,   1.02130713, 1.01323145, 1.00521156, 0.99724708,
        0.9893376,  0.98148274, 0.97368211, 0.96593534, 0.95824203, 0.95060182,
        0.94301433, 0.93547919, 0.92799604, 0.92056451, 0.91318425, 0.90585489]

        thetad_sdm = [299.9237387,  299.90192459, 299.88010651, 299.85828446, 299.83645843,
        299.81462843, 299.79279445, 299.82598628, 300.35429564, 300.8823342,
        301.41010174, 301.93759804, 302.46482289, 302.99177605, 303.5184573,
        304.04486643, 304.5710032,  305.0968674,  305.6224588,  306.14777717,
        306.6728223,  307.19759395, 307.7220919,  308.24631593, 308.7702658,
        309.29394129, 309.81734218, 310.34046824, 310.86331923, 311.38589493]

        T_sdm = [297.89146141, 296.91169302, 295.93187902, 294.95201942, 293.9721142,
        292.99216335, 292.01216688, 291.11060787, 290.91080025, 290.70836601,
        290.50358034, 290.29644503, 290.0869619,  289.87513271, 289.66095927,
        289.44444334, 289.22558669, 289.0043911,  288.78085832, 288.55499011,
        288.32678822, 288.0962544,  287.86339037, 287.62819788, 287.39067865,
        287.1508344,  286.90866686, 286.66417773, 286.41736872, 286.16824153]

        P_sdm = [99989.96354954, 98843.0930032,  97705.5985201,  96577.43471453,
        95458.55626559, 94348.9179173,  93248.47447883, 92180.75445213,
        91329.18053725, 90483.68082619, 89644.51894239, 88811.65560125,
        87985.05175116, 87164.66857176, 86350.4674723,  85542.41008992,
        84740.45828806, 83944.57415472, 83154.72000095, 82370.85835915,
        81592.95198151, 80820.96383845, 80054.85711701, 79294.59521933,
        78540.1417611,  77791.46057006, 77048.51568443, 76311.27135151,
        75579.6920261,  74853.7423691]

    elseif case=="dry_coarse"
        # Reference data from PySDM
        z_sdm = [50.,  150.,  250.,  350.,  450.,  550.,  650.,  750.,  850.,  950., 1050., 1150.,
        1250., 1350., 1450., 1550., 1650., 1750., 1850., 1950., 2050., 2150., 2250., 2350.,
        2450., 2550., 2650., 2750., 2850., 2950.]

        ql_sdm = [0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.,
        0., 0., 0., 0., 0., 0.]

        qv_sdm = [0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0.,
        0., 0., 0., 0., 0., 0.]

        rhod_sdm = [1.16952124, 1.15996088, 1.15044759, 1.14098128, 1.13156189, 1.12218932,
        1.11286352, 1.1035846,  1.09436723, 1.08522133, 1.07614632, 1.06714161,
        1.05820664, 1.04934087, 1.04054372, 1.03181466, 1.02315314, 1.01455862,
        1.00603057, 0.99756846, 0.98917176, 0.98083996, 0.97257254, 0.96436899,
        0.9562288,  0.94815149, 0.94013654, 0.93218346, 0.92429178, 0.916461]

        thetad_sdm = [297.9,        297.9,        297.9,        297.9,        297.9,
        297.9,        297.9,        297.95857143, 298.54428571, 299.13,
        299.71571429, 300.30142857, 300.88714286, 301.47285714, 302.05857143,
        302.64428571, 303.23,       303.81571429, 304.40142857, 304.98714286,
        305.57285714, 306.15857143, 306.74428571, 307.33,       307.91571429,
        308.50142857, 309.08714286, 309.67285714, 310.25857143, 310.84428571]

        T_sdm = [297.89029583, 296.91450976, 295.93872369, 294.96293762, 293.98715155,
        293.01136548, 292.03557941, 291.13992023, 290.96418339, 290.78639524,
        290.60655649, 290.42466954, 290.2407368,  290.05476065, 289.86674347,
        289.67668765, 289.48459556, 289.29046955, 289.09431198, 288.8961252,
        288.69591154, 288.49367335, 288.28941294, 288.08313264, 287.87483475,
        287.66452159, 287.45219544, 287.23785861, 287.02151336, 286.80316199]

        P_sdm = [99988.59355485, 98846.37661162, 97713.51209532, 96589.95388752,
        95475.65594602, 94370.57230496, 93274.65707496, 92213.26077185,
        91387.87992297, 90568.75464708, 89755.84108282, 88949.09754969,
        88148.48264873, 87353.95526028, 86565.4745417,  85782.99992528,
        85006.49111597, 84235.90808929, 83471.21108917, 82712.36062585,
        81959.31747379, 81212.04266959, 80470.49750994, 79734.64354961,
        79004.4425994,  78279.85672419, 77560.84824092, 76847.37971668,
        76139.41396674, 75436.91405264]
    end

#! format: on

    qv_sdm = qv_sdm ./ (1 .+ qv_sdm)
    rho_sdm = rhod_sdm .* (1 .+ qv_sdm)

    return (; z_sdm, qv_sdm, rho_sdm, thetad_sdm, T_sdm, P_sdm, ql_sdm)
end
